package com.academiaandroid.stockferreteria;

import android.app.Activity;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.Toast;

import com.academiaandroid.stockferreteria.EstructuraDatos.Estructura;

//Ejemplo aplicacin Android en el que utilizamos la API SQLite para realizar
//operaciones sobre una Base de Datos
//
//academiaandroid.com
//
//by Jos Antonio Gzquez Rodrguez

public class MainActivity extends Activity {

	//Declaramos los controles necesarios para la lgica de la aplicacin
	private EditText edProducto;
	private EditText edCantidad;
	private EditText edId;
	private Spinner spnSeccion;
	//Declaramos la clase encargada de crear y actualizar la Base de Datos 
	MiBaseDatos basedatos;
	
	//Definimos el mensaje que mostrar la columna 'Tag'
	private static final String LOGTAG = "Academia Android: MainActivity.java ->";
	
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        //Enlazamos los controles definidos con sus recursos a nivel de layout
        edProducto = (EditText)findViewById(R.id.edProducto);
        edCantidad = (EditText)findViewById(R.id.edCantidad);
        spnSeccion = (Spinner)findViewById(R.id.spinnerSeccion);
        edId = (EditText)findViewById(R.id.edIdentificador);
        
        //Creamos un Array de String con las secciones de una ferretera
        String[] secciones = {"Electricidad","Fontanera","Cerrajera","Jardinera","Tornillera","Vestimenta"};
        spnSeccion.setAdapter(new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, secciones));
    }

    //Evento On Click para guardar un producto en la tabla Ventas
    public void guardarProducto(View view)
    {
    	//Guardamos un registro de tipo 'Info' al lanzar el evento On CLick 'guardarProducto'
    	Log.i(LOGTAG,"Se ha lanzado el evento On Click para guardar un Producto");
    	//Se inicializa la clase.
    	basedatos = new MiBaseDatos(this);
    	//Clase que permite llamar a los mtodos para crear, eliminar, leer y actualizar registros. Se establecen permisos de escritura.
    	SQLiteDatabase sqlite = basedatos.getWritableDatabase();    	
    	try
    	{  	
	    	String producto = edProducto.getText().toString();
	    	String cantidad = edCantidad.getText().toString();
	    	String seccion = spnSeccion.getSelectedItem().toString();
	    	
	    	ContentValues content = new ContentValues();
	    	
	    	if(producto.equals("") || cantidad.equals(""))
	    	{
	    		Toast.makeText(this, "Revise los datos introducidos. Todos los campos son obligatorios.", 3000).show();
	    	}else
	    	{
	    		
	    		//Se aaden los valores introducidos de cada campo mediante clave(columna)/valor(valor introducido en el campo de texto)
		    	content.put(Estructura.COLUMN_NAME_PRODUCTO, producto);
		    	content.put(Estructura.COLUMN_NAME_CANTIDAD, cantidad);
		    	content.put(Estructura.COLUMN_NAME_SECCION, seccion);
		    	sqlite.insert(Estructura.TABLE_NAME, null, content);
		    	//Guardamos un registro de tipo 'Debug' en la llamada al mtodo que guarda el producto
		    	Log.d(LOGTAG,"Se ha guardado un Producto");
		    	Toast.makeText(this, "Producto " + producto + " ha sido almacenado.", 3000).show();
		    	edProducto.setText("");
		    	edCantidad.setText("");
		    	edId.setText("");		    	
	    	}
    	}catch(Exception ex)
    	{
    		Log.e(LOGTAG + "Error al guardar un producto: ",ex.getMessage());
    	}
    	finally
    	{
    		//Se cierra la conexin abierta a la Base de Datos
        	sqlite.close();
    	}
    	
    }
    
    //Evento On Click para buscar un producto en la tabla Ventas por nombre
    public void buscarProducto(View view)
    {
    	//Guardamos un registro de tipo 'Info' al lanzar el evento On CLick 'buscarProducto'
    	Log.i(LOGTAG,"Se ha lanzado el evento On Click para buscar un Producto");
    	//Se inicializa la clase.
    	basedatos = new MiBaseDatos(this);
    	//Se establecen permisos de lectura
    	SQLiteDatabase sqlite = basedatos.getReadableDatabase();
    	
    	try{
		    	//Columnas que devolver la consulta.
		    	String[] columnas = {
		    		    Estructura._ID,
		    		    Estructura.COLUMN_NAME_PRODUCTO,
		    		    Estructura.COLUMN_NAME_CANTIDAD,
		    		    Estructura.COLUMN_NAME_SECCION
		    		    };
		    	
		    	//Clusula WHERE para buscar por producto
		    	String producto = Estructura.COLUMN_NAME_PRODUCTO + " LIKE '" +  edProducto.getText().toString() + "'";
		    	//Orden de los resultados devueltos por Producto, de forma Descendente alfabticamente
		    	String ordenSalida = Estructura.COLUMN_NAME_PRODUCTO + " DESC";
		    	
		    	if(producto.equals(""))    		
		    	{
		    		Toast.makeText(this, "Debe indicar el producto a buscar en la base de datos.", 3000).show();
		    	}else
		    	{
		    		//Ejecuta la sentencia devolviendo los resultados de los parmetros pasados de tabla, columnas, producto y orden de los resultados.
		    		Cursor cursor = sqlite.query(Estructura.TABLE_NAME, columnas, producto,null , null, null, ordenSalida);
			    		
			    	if(cursor.getCount() != 0)
			    	{
			    			cursor.moveToFirst();
			    		
					    	long identificador = cursor.getLong(cursor.getColumnIndex(Estructura._ID));
					    	//Guardamos un registro de tipo 'Debug' en la llamada al mtodo que busca el producto
					    	Log.d(LOGTAG,"Se ha buscado un Producto");
					    	Toast.makeText(this, "El Producto " +  edProducto.getText().toString()
					    			 + " est almacenado con Identificador " + identificador, 3000).show();
					    	edProducto.setText("");
					    	edCantidad.setText("");
					    	edId.setText("");
			    		
			    	}
			    	else
			    	{
			    		Toast.makeText(this, "El Producto '" + edProducto.getText().toString()  + "' no existe en la Base de Datos.", 3000).show();
			    	}
		    	}
	    	
	    	}catch(Exception ex)
			{
				Log.e(LOGTAG + "Error al buscar un producto: ",ex.getMessage());
			}
			finally
			{
				//Se cierra la conexin abierta a la Base de Datos
		    	sqlite.close();
			}

    }
    
    //Evento On Click para eliminar un producto de la tabla Ventas por el nombre
    public void borrarProducto(View view)
    {
    	//Guardamos un registro de tipo 'Info' al lanzar el evento On CLick 'borrarProducto'
    	Log.i(LOGTAG,"Se ha lanzado el evento On Click para borrar un Producto");
    	String producto_eliminar = edProducto.getText().toString();
    	//Se inicializa la clase.
    	basedatos = new MiBaseDatos(this);
    	//Se establecen permisos de escritura
    	SQLiteDatabase sqlite = basedatos.getWritableDatabase();
    	try{		    	
		    	if(producto_eliminar.equals(""))    		
		    	{
		    		Toast.makeText(this, "Debe indicar el producto a eliminar de la base de datos.", 3000).show();
		    	}else
		    	{
		    		//Se especifica el campo Producto y el producto introducido en el campo de texto a eliminar
			    	String consulta = Estructura.COLUMN_NAME_PRODUCTO + " LIKE '" + producto_eliminar + "'";
			    	//Se borra el producto indicado en el campo de texto
			    	sqlite.delete(Estructura.TABLE_NAME, consulta, null);
			    	//Guardamos un registro de tipo 'Debug' en la llamada al mtodo que borra el producto
			    	Log.d(LOGTAG,"Se ha borrado un Producto");
			    	Toast.makeText(this, "Se ha eliminado el producto: " + producto_eliminar, 3000).show();
			    	edProducto.setText("");
			    	edCantidad.setText("");
			    	edId.setText("");
			    	
		    	}
		    }catch(Exception ex)
			{
				Log.e(LOGTAG + "Error al borrar un producto: ",ex.getMessage());
			}
			finally
			{
				//Se cierra la conexin abierta a la Base de Datos
		    	sqlite.close();
			}
    }
    
    //Evento On Click para modificar un producto de la tabla Ventas. Todos los campos son modificables, excepto el campo _id
    public void modificarProducto(View view)
    {
    	//Guardamos un registro de tipo 'Info' al lanzar el evento On CLick 'modificarProducto'
    	Log.i(LOGTAG,"Se ha lanzado el evento On Click para modificar un Producto");
    	//Se inicializa la clase.
    	basedatos = new MiBaseDatos(this);
    	
    	//Se establecen permisos de escritura
    	SQLiteDatabase sqlite = basedatos.getWritableDatabase();
    	try{
		    	Long identificador = Long.valueOf(edId.getText().toString()); 
		    	String producto_modificar = edProducto.getText().toString();
		    	String cantidad_modificar = edCantidad.getText().toString();
		    	String seccion_modificar = spnSeccion.getSelectedItem().toString();
		    	
		    	ContentValues content = new ContentValues();
		    	//Se aaden los valores introducidos de cada campo mediante clave(columna)/valor(valor introducido en el campo de texto)
		    	content.put(Estructura.COLUMN_NAME_PRODUCTO, producto_modificar);
		    	content.put(Estructura.COLUMN_NAME_CANTIDAD, cantidad_modificar);
		    	content.put(Estructura.COLUMN_NAME_SECCION, seccion_modificar);
		    	if(producto_modificar.equals("") || cantidad_modificar.equals(""))    
		    	{
		    		Toast.makeText(this, "Revise los datos introducidos. Todos los campos son obligatorios.", 3000).show();
		    	}else
		    	{
		    		//Se establece la condicin del _id del producto a modificar
		    		String selection = Estructura._ID + " LIKE " + identificador;
		    		
		    		//Se llama al mtodo update pasndole los parmetros para modificar el producto con el identificado como condicin de bsqueda
		    		int count = sqlite.update(
			    	    Estructura.TABLE_NAME,
			    	    content,
			    	    selection,
			    	    null);
		    		//Guardamos un registro de tipo 'Debug' en la llamada al mtodo que modifica el producto
		    		Log.d(LOGTAG,"Se ha modificado un Producto");
		    		Toast.makeText(this, "Se ha actualizado el producto: " + producto_modificar + 
		    				". Registros modificados: " + count, 3000).show();
		    		edProducto.setText("");
			    	edCantidad.setText("");
			    	edId.setText("");
		    	}
    	}catch(Exception ex)
    	{
    		//Al cazar la excepcin de no introducir ningn valor en el campo 'Total', muestra el mensaje de error en LogCat
    		Log.e(LOGTAG + "Error al modificar un producto: ",ex.getMessage());
    	}
    	finally
    	{
    		//Se cierra la conexin abierta a la Base de Datos
        	sqlite.close();
    	}
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }
    
}
